<?php

/*
Plugin Name:  FreeFeatures
Version: 1.0.4
Description: Embed FreeFeatures content in your website
Author: FreeFeatures
Author URI: https://www.freefeatures.co.uk/
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: freefeatures
*/

add_shortcode('freefeatures_feature', 'freefeatures_embed_feature');
add_shortcode('freefeatures_recipe', 'freefeatures_embed_recipe');
add_shortcode('freefeatures_review', 'freefeatures_embed_review');

function freefeatures_fetch_item($id, $type) {
    $params = array(
        't' => $id,
        'l' => get_site_url()
    );

    $res = wp_remote_post('https://api.freefeatures.co.uk/api/v1/' . $type . 's', array(
        'headers'     => array('Content-Type' => 'application/json; charset=utf-8'),
        'body'        => json_encode($params),
        'method'      => 'POST',
        'data_format' => 'body',
    ));

    if(is_wp_error($res)) {
        return $res;
    }

    return json_decode(wp_remote_retrieve_body($res));
}

function freefeatures_get_item($id, $expire, $type) {
    if(! $item = wp_cache_get($id, 'freefeatures')) {
        $item = freefeatures_fetch_item($id, $type);

        if(is_wp_error($item)) {
            return $item;
        }

        // max cache time is 1 hour
        $cache_expire = $expire > 60 ? 60 : $expire <= 0 ? 60 : $expire;
        wp_cache_add($id, $item, 'freefeatures', $cache_expire * 60);
    }
    return $item;
}

function freefeatures_embed_feature($atts = array(), $content = null, $tag = '') {
    $args = wp_parse_args($atts, array('expire' => 60, 'error_redirect' => null));
    $id = $args['id'];
    $cache_expire = intval($args['expire']) || 60;

    $feature = freefeatures_get_item($id, $cache_expire, "article");
    if(is_wp_error($feature)) {
        return '<p>Content can not be loaded at this time</p>';
    }
    wp_enqueue_script( 'ff-feature-script', $feature->analytics);
    return $feature->html;

}

function freefeatures_embed_recipe($atts = array(), $content = null, $tag = '') {
    $args = wp_parse_args($atts, array('expire' => 60, 'error_redirect' => null));
    $id = $args['id'];
    $cache_expire = intval($args['expire']) || 60;

    $recipe = freefeatures_get_item($id, $cache_expire, "recipe");
    if(is_wp_error($recipe)) {
        return '<p>Content can not be loaded at this time</p>';
    }
    wp_enqueue_script( 'ff-feature-script', $recipe->analytics);
    return $recipe->html;
}

function freefeatures_embed_review($atts = array(), $content = null, $tag = '') {
    $args = wp_parse_args($atts, array('expire' => 60, 'error_redirect' => null));
    $id = $args['id'];
    $cache_expire = intval($args['expire']) || 60;

    $review = freefeatures_get_item($id, $cache_expire, "review");
    if(is_wp_error($review)) {
        return '<p>Content can not be loaded at this time</p>';
    }
    wp_enqueue_script( 'ff-feature-script', $review->analytics);
    return $review->html;
}

function freefeatures_embed_scripts() {
    global $post;
    if( is_a( $post, 'WP_Post' ) && has_shortcode( $post->post_content, 'freefeatures_feature') ) {
        wp_register_style( 'freefeatures_feature-stylesheet',  'https://api.freefeatures.co.uk/api/v1/articles/scripts/css' );
        wp_enqueue_style( 'freefeatures_feature-stylesheet' );

    }

    if( is_a( $post, 'WP_Post' ) && has_shortcode( $post->post_content, 'freefeatures_recipe') ) {
        wp_register_style( 'freefeatures_recipe-stylesheet',  'https://api.freefeatures.co.uk/api/v1/recipes/scripts/css' );
        wp_enqueue_style( 'freefeatures_recipe-stylesheet' );

    }

    if( is_a( $post, 'WP_Post' ) && has_shortcode( $post->post_content, 'freefeatures_review') ) {
        wp_register_style( 'freefeatures_review-stylesheet',  'https://api.freefeatures.co.uk/api/v1/reviews/scripts/css' );
        wp_enqueue_style( 'freefeatures_review-stylesheet' );
    }
}

function freefeatures_meta_tags() {
    global $post;
    $regex_pattern = get_shortcode_regex();
    preg_match_all ('/'.$regex_pattern.'/s', $post->post_content, $regex_matches);

    $tag = $regex_matches[2][0];
    $code = $regex_matches[0][0];
    if ($regex_matches[2][0] == 'freefeatures_feature') {
        $attributes = shortcode_parse_atts($regex_matches[3][0]);
        if (isset ($attributes["id"])) {
            $id = $attributes["id"];
            $expire = isset($attributes["expire"]) ? intval($attributes["expire"]) || 60 : 60;
            $feature = freefeatures_get_item($id, $expire, "article");
            if(!is_wp_error($feature)) {
                echo '<meta property="og:title" content="' . $feature->meta->title .'" />';
                echo '<meta property="og:description" content="' . $feature->meta->summary .'" />';
                echo '<meta property="og:image" content="' . $feature->meta->image .'" />';
            }
        }
    } elseif ($regex_matches[2][0] == 'freefeatures_recipe') {
        $attributes = shortcode_parse_atts($regex_matches[3][0]);

        if (isset ($attributes["id"])) {
            $id = $attributes["id"];
            $expire = isset($attributes["expire"]) ? intval($attributes["expire"]) || 60 : 60;
            $recipe = freefeatures_get_item($id, $expire, "recipe");
            if(!is_wp_error($recipe) && !is_null($recipe->meta)) {
                echo '<meta property="og:title" content="' . $recipe->meta->title .'" />';
                echo '<meta property="og:description" content="' . $recipe->meta->summary .'" />';
                echo '<meta property="og:image" content="' . $recipe->meta->image .'" />';
            }
        }
    } elseif ($regex_matches[2][0] == 'freefeatures_review') {
        $attributes = shortcode_parse_atts($regex_matches[3][0]);

        if (isset ($attributes["id"])) {
            $id = $attributes["id"];
            $expire = isset($attributes["expire"]) ? intval($attributes["expire"]) || 60 : 60;
            $review = freefeatures_get_item($id, $expire, "review");
            if(!is_wp_error($review) && !is_null($review->meta)) {
                echo '<meta property="og:title" content="' . $review->meta->title .'" />';
                echo '<meta property="og:description" content="' . $review->meta->summary .'" />';
                echo '<meta property="og:image" content="' . $review->meta->image .'" />';
            }
        }
    }

}

add_action( 'wp_enqueue_scripts', 'freefeatures_embed_scripts');
add_action('wp_head', 'freefeatures_meta_tags');


